@@ -83,7 +83,7 @@ class Forum(object):
             result['posts'] = posts_next[:20]
             tpage = page - 1
             t_off=20
-            while tpage > 1 and tpage != 1:
+            while tpage > 1 and tpage >= page-2:
                 result['current'].append((tpage, posts_before[1-t_off].id))
                 t_off += 20
                 tpage -= 1
